// abilities.js

// Functions specific to the 3ED&D General Extended PCProfiler template.
// These functions apply to the ability scores and events that occur when
// they are changed.
// Dependencies: general.js, bab.js, saves.js, init.js, ac.js, skills.js

function OnAbilityChanged(inAbility)
{
    // Starts the string of functions that are called when an ability is
    // is changed. This is the only function that is called from the
    // document.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    if (IsTempAbility(inAbility))
        if (inAbility.value == "")
        {
            // Value was cleared. Clear the temp mod, then apply the
            // normal ability mod 
            DeleteTempMod(inAbility);
            RecalcAbDep(inAbility, false);
            window.status = "Cleared " + GenerateAbilityName(inAbility) + " modifier. Normal modifier applied where appropriate.";
        }
        else
        {
            // Value was added/modified. Apply the change, and use the
            // temp mod on all dependent fields.
            ChangeMod(inAbility);
            RecalcAbDep(inAbility, true);
            window.status = "Changed " + GenerateAbilityName(inAbility) + " modifier. Temp mod applied where appropriate.";
        }
    else
    {
        // Dealing with a normal ability. Calculate the mod and write it.
        ChangeMod(inAbility);
        if (DoesTempExist(inAbility))
        {
            // If a temp mod exists, do nothing.
            window.status = "Changed " + GenerateAbilityName(inAbility) + " modifier. Temp Mod exists: no further modifications were made.";
        }
        else
        {
            // No temp mod exists, apply as normal.
            RecalcAbDep(inAbility, false);
            window.status = "Changed " + GenerateAbilityName(inAbility) + " modifier. Recalculated where appropriate.";
        }
    }
}

function IsTempAbility(inAbility)
{
    // Returns true if the inAbility argument is a Temporary Ability input.
    var myAbNames = new Array("Str", "Dex", "Con", "Int", "Wis", "Cha");
    for (var i in myAbNames)
        if (inAbility.name == myAbNames[i])
            return false;
    return true;
}

function DoesTempExist(inAbility)
{
    // Called with a normal ability as inAbility.
    // Returns true if a valid temporary modifier exists for the specified
    // normal ability.
    var myTempName = inAbility.name + "TempMod";
    var myMod = parseInt(document.all[myTempName].value);
    if (isNaN(myMod))
        return false;
    return true;
}

function ChangeMod(inAbility)
{
    // Changes the the modifier associated with the specified by inAbility.
    var myModName = inAbility.name + "Mod";
    document.all[myModName].value = CalculateMod(inAbility.value);
}

function DeleteTempMod(inAbility)
{
    // Value was cleared. Delete the temp odifier.
    var myTempMod = inAbility.name + "Mod";
    document.all[myTempMod].value = "";
}

function GenerateAbilityName(inAbility)
{
    // Returns string describing the proper ability name.
    switch (inAbility.name)
    {
        case "Str":
            return "strength";
        case "Dex":
            return "dexterity";
        case "Con":
            return "constitution";
        case "Int":
            return "intelligence";
        case "Wis":
            return "wisdom";
        case "Cha":
            return "charisma";
        case "StrTemp":
            return "temporary strength";
        case "DexTemp":
            return "temporary dexterity";
        case "ConTemp":
            return "temporary constitution";
        case "IntTemp":
            return "temporary intelligence";
        case "WisTemp":
            return "temporary wisdom";
        case "ChaTemp":
            return "temporary charisma";
    }
}

function RecalcAbDep(inAbility, bUseTemp)
{
    // Copies the modifier corresponding to inAbility to the appropriate
    // inputs. Uses the temp mod if bUseTemp is true.
    var myInName = inAbility.name;
    if ((myInName == "Str") || (myInName == "StrTemp"))
        ApplyStr(bUseTemp);
    else if ((myInName == "Dex") || (myInName == "DexTemp"))
        ApplyDex(bUseTemp);
    else if ((myInName == "Con") || (myInName == "ConTemp"))
        ApplyCon(bUseTemp);
    else if ((myInName == "Int") || (myInName == "IntTemp"))
        ApplyInt(bUseTemp);
    else if ((myInName == "Wis") || (myInName == "WisTemp"))
        ApplyWis(bUseTemp);
    else if ((myInName == "Cha") || (myInName == "ChaTemp"))
        ApplyCha(bUseTemp);
}

function ApplyStr(bUseTemp)
{
    // Applies the strength modifier to dependent fields.
    var myMod;
    if (bUseTemp)
        myMod = parseInt(document.all.StrTempMod.value);
    else
        myMod = parseInt(document.all.StrMod.value);
    if (isNaN(myMod))
        myMod = 0;

    // Apply to Melee AB.
    document.all.MABStr.value = myMod;
    ParsedAdd(true);
    
    // Apply to skills.
    CalcSkills("Str", myMod);
}

function ApplyDex(bUseTemp)
{
    // Applies the dexterity modifier to dependent fields.
    var myMod;
    if (bUseTemp)
        myMod = parseInt(document.all.DexTempMod.value);
    else
        myMod = parseInt(document.all.DexMod.value);
    if (isNaN(myMod))
        myMod = 0;
    
    // Apply to Ranged AB.
    document.all.RABDex.value = myMod;
    ParsedAdd(false);
    
    // Apply to Reflex Save.
    document.all.ReflexAbility.value = myMod;
    CalcSave("Reflex");
    
    // Apply to initiative.
    document.all.InitDex.value = myMod;
    CalcInit();
    
    // Apply to Armor Class.
    document.all.ACDex.value = myMod;
    CalcAC();
    
    // Apply to Skills.
    CalcSkills("Dex", myMod);
}

function ApplyCon(bUseTemp)
{
    // Applies the constitution modifier...
    var myMod;
    if (bUseTemp)
        myMod = parseInt(document.all.ConTempMod.value);
    else
        myMod = parseInt(document.all.ConMod.value);
    if (isNaN(myMod))
        myMod = 0;
    
    // Apply to Fortitude Save.
    document.all.FortAbility.value = myMod;
    CalcSave("Fort");
    
    // Apply to Skills.
    CalcSkills("Con", myMod);
}

function ApplyInt(bUseTemp)
{
    // Applies the intelligence modifier...
    var myMod;
    if (bUseTemp)
        myMod = parseInt(document.all.IntTempMod.value);
    else
        myMod = parseInt(document.all.IntMod.value);
    if (isNaN(myMod))
        myMod = 0;
    
    // Apply to skills.
    CalcSkills("Int", myMod);
}

function ApplyWis(bUseTemp)
{
    // Apply the Wisdom...
    var myMod;
    if (bUseTemp)
        myMod = parseInt(document.all.WisTempMod.value);
    else
        myMod = parseInt(document.all.WisMod.value);
    if (isNaN(myMod))
        myMod = 0;
    
    // Apply to the Will Save.
    document.all.WillAbility.value = myMod;
    CalcSave("Will");
    
    // Apply to skills.
    CalcSkills("Wis", myMod);
}

function ApplyCha(bUseTemp)
{
    // Apply the charisma...
    var myMod;
    if (bUseTemp)
        myMod = parseInt(document.all.ChaTempMod.value);
    else
        myMod = parseInt(document.all.ChaMod.value);
    if (isNaN(myMod))
        myMod = 0;
    
    // Apply to skills.
    CalcSkills("Cha", myMod);
}